==> haskell-isomorphism-class-0.1.1-61-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-isomorphism-class.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 isomorphism-class
version:              0.1.1
visibility:           public
id:                   isomorphism-class-0.1.1-GuloKIPyvm6GzUrqZrHNx4
key:                  isomorphism-class-0.1.1-GuloKIPyvm6GzUrqZrHNx4
license:              MIT
copyright:            (c) 2022 Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/isomorphism-class
synopsis:             Isomorphism typeclass solving the conversion problem
description:          Lawful typeclass for lossless conversion between types.
category:             Conversion
abi:                  8eb5efac69afddb2ce46b9e90ed7b6bd
exposed:              True
exposed-modules:      IsomorphismClass
hidden-modules:
    IsomorphismClass.Prelude IsomorphismClass.TextCompat.Array

import-dirs:          /usr/lib/ghc-9.4.8/site-local/isomorphism-class-0.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/isomorphism-class-0.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/isomorphism-class-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-isomorphism-class
hs-libraries:         HSisomorphism-class-0.1.1-GuloKIPyvm6GzUrqZrHNx4
depends:
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    hashable-1.4.4.0-HF0gObldLcB4LirfpxeD3R
    primitive-0.9.1.0-CwYB76NvKpqXNq7rVKe89 text-2.0.2
    unordered-containers-0.2.20-89DcpQLd7HI30AdGz5XyJk
    vector-0.13.2.0-AtXaKVcIvtCInBZOrzSe57

haddock-interfaces:
    /usr/share/doc/haskell-isomorphism-class/html/isomorphism-class.haddock

haddock-html:         /usr/share/doc/haskell-isomorphism-class/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-isomorphism-class-0.1.1-82-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-isomorphism-class.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 isomorphism-class
version:              0.1.1
visibility:           public
id:                   isomorphism-class-0.1.1-KirXgBKea6QKtx4ZtZ1FUf
key:                  isomorphism-class-0.1.1-KirXgBKea6QKtx4ZtZ1FUf
license:              MIT
copyright:            (c) 2022 Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/isomorphism-class
synopsis:             Isomorphism typeclass solving the conversion problem
description:          Lawful typeclass for lossless conversion between types.
category:             Conversion
abi:                  4534c2d990e192a1fbd72e355efd1518
exposed:              True
exposed-modules:      IsomorphismClass
hidden-modules:
    IsomorphismClass.Prelude IsomorphismClass.TextCompat.Array

import-dirs:          /usr/lib/ghc-9.4.8/site-local/isomorphism-class-0.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/isomorphism-class-0.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/isomorphism-class-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-isomorphism-class
hs-libraries:         HSisomorphism-class-0.1.1-KirXgBKea6QKtx4ZtZ1FUf
depends:
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    hashable-1.4.7.0-KrA5CwhmktQ6Qu5a4JCqq7
    primitive-0.9.1.0-1TuYyil4nabJdMHni5vWH text-2.0.2
    unordered-containers-0.2.20.1-JRJBW0Nl9iEJULI134IWXM
    vector-0.13.2.0-DhQEcquLn8PDmAHUsOvAGS

haddock-interfaces:
    /usr/share/doc/haskell-isomorphism-class/html/isomorphism-class.haddock

haddock-html:         /usr/share/doc/haskell-isomorphism-class/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
